@@ -18,4 +18,4 @@
 
 from .main import main
 
-__all__ = ['main']
+__all__ = ["main"]
