@@ -33,8 +33,10 @@ from pontos.github.api import GitHubAsyncRESTApi
 from pontos.helper import AsyncDownloadProgressIterable
 from pontos.terminal import Terminal
 from pontos.terminal.rich import RichTerminal
+from pontos.version.helper import get_last_release_version
+from pontos.version.version import Version
 
-from .helper import get_git_repository_name, get_last_release_version
+from .helper import get_git_repository_name
 
 
 class SignReturnValue(IntEnum):
@@ -172,7 +174,7 @@ class SignCommand:
         project: Optional[str],
         space: str,
         git_tag_prefix: Optional[str],
-        release_version: Optional[str],
+        release_version: Optional[Version],
         signing_key: str,
         passphrase: str,
     ) -> SignReturnValue:
