@@ -15,13 +15,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from typing import Any, Dict, Tuple
 from unittest.mock import MagicMock
 
 import httpx
 
 from pontos.github.api.client import GitHubAsyncREST, GitHubAsyncRESTClient
-from pontos.github.api.helper import DEFAULT_TIMEOUT_CONFIG
 from tests import AsyncMock, IsolatedAsyncioTestCase
 
 
@@ -29,20 +27,6 @@ def create_response(*args, **kwargs) -> MagicMock:
     return MagicMock(spec=httpx.Response, *args, **kwargs)
 
 
-def default_request(*args, **kwargs) -> Tuple[Tuple[Any], Dict[str, Any]]:
-    default_kwargs = {
-        "follow_redirects": True,
-        "headers": {
-            "Authorization": "token 12345",
-            "Accept": "application/vnd.github.v3+json",
-        },
-        "params": None,
-        "timeout": DEFAULT_TIMEOUT_CONFIG,
-    }
-    default_kwargs.update(kwargs)
-    return args, default_kwargs
-
-
 class GitHubAsyncRESTTestCase(IsolatedAsyncioTestCase):
     api_cls = GitHubAsyncREST
 
