@@ -18,14 +18,13 @@
 # pylint: disable=invalid-name, protected-access
 
 import unittest
-
 from io import StringIO
-from unittest.mock import patch, MagicMock, Mock
+from unittest.mock import MagicMock, patch
 
 import colorful as cf
 
-from pontos.terminal.terminal import Terminal, Signs
-from pontos.terminal import _set_terminal, error, fail, info, ok, out, warning
+from pontos.terminal.terminal import ConsoleTerminal as Terminal
+from pontos.terminal.terminal import Signs
 
 
 class TerminalTestCase(unittest.TestCase):
@@ -36,18 +35,19 @@ class TerminalTestCase(unittest.TestCase):
         self.green = cf.green
         self.yellow = cf.yellow
         self.cyan = cf.cyan
+        self.white = cf.white
         self.reset = cf.reset
         self.bold = cf.bold
         # every colors second value is the reset value ...
         self.term = Terminal()
         self.term.get_width = MagicMock(return_value=80)
 
-    @patch('sys.stdout', new_callable=StringIO)
+    @patch("sys.stdout", new_callable=StringIO)
     def test_error(self, mock_stdout):
-        status = f'{self.red(Signs.ERROR)} '
-        msg = 'foo bar'
+        status = f"{self.red(Signs.ERROR)} "
+        msg = "foo bar"
 
-        expected_msg = self.reset(f'{status}{msg}').styled_string + '\n'
+        expected_msg = self.reset(f"{status}{msg}").styled_string + "\n"
         expected_len = len(expected_msg)
 
         self.term.error(msg)
@@ -57,12 +57,12 @@ class TerminalTestCase(unittest.TestCase):
         self.assertEqual(ret, expected_msg)
         self.assertEqual(len(ret), expected_len)
 
-    @patch('sys.stdout', new_callable=StringIO)
+    @patch("sys.stdout", new_callable=StringIO)
     def test_fail(self, mock_stdout):
-        status = f'{self.red(Signs.FAIL)} '
-        msg = 'foo bar baz'
+        status = f"{self.red(Signs.FAIL)} "
+        msg = "foo bar baz"
 
-        expected_msg = self.reset(f'{status}{msg}').styled_string + '\n'
+        expected_msg = self.reset(f"{status}{msg}").styled_string + "\n"
         expected_len = len(expected_msg)
 
         self.term.fail(msg)
@@ -72,12 +72,12 @@ class TerminalTestCase(unittest.TestCase):
         self.assertEqual(ret, expected_msg)
         self.assertEqual(len(ret), expected_len)
 
-    @patch('sys.stdout', new_callable=StringIO)
+    @patch("sys.stdout", new_callable=StringIO)
     def test_info(self, mock_stdout):
-        status = f'{self.cyan(Signs.INFO)} '
-        msg = 'foo bar'
+        status = f"{self.cyan(Signs.INFO)} "
+        msg = "foo bar"
 
-        expected_msg = self.reset(f'{status}{msg}').styled_string + '\n'
+        expected_msg = self.reset(f"{status}{msg}").styled_string + "\n"
         expected_len = len(expected_msg)
 
         self.term.info(msg)
@@ -87,12 +87,28 @@ class TerminalTestCase(unittest.TestCase):
         self.assertEqual(ret, expected_msg)
         self.assertEqual(len(ret), expected_len)
 
-    @patch('sys.stdout', new_callable=StringIO)
-    def test_bold_info(self, mock_stdout):
-        status = f'{self.cyan(Signs.INFO)} '
-        msg = 'bold foo bar'
+    @patch("sys.stdout", new_callable=StringIO)
+    def test_info_with_newline(self, mock_stdout):
+        status = f"{self.cyan(Signs.INFO)} "
+        msg = "foo bar\nbaz"
+        repl_msg = msg.replace("\n", "\n  ")
 
-        expected_msg = self.bold(f'{status}{msg}').styled_string + '\n'
+        expected_msg = self.reset(f"{status}{repl_msg}").styled_string + "\n"
+        expected_len = len(expected_msg)
+
+        self.term.info(msg)
+
+        ret = mock_stdout.getvalue()
+
+        self.assertEqual(ret, expected_msg)
+        self.assertEqual(len(ret), expected_len)
+
+    @patch("sys.stdout", new_callable=StringIO)
+    def test_bold_info(self, mock_stdout):
+        status = f"{self.cyan(Signs.INFO)} "
+        msg = "bold foo bar"
+
+        expected_msg = self.bold(f"{status}{msg}").styled_string + "\n"
         expected_len = len(expected_msg)
 
         self.term.bold_info(msg)
@@ -102,12 +118,12 @@ class TerminalTestCase(unittest.TestCase):
         self.assertEqual(ret, expected_msg)
         self.assertEqual(len(ret), expected_len)
 
-    @patch('sys.stdout', new_callable=StringIO)
+    @patch("sys.stdout", new_callable=StringIO)
     def test_ok(self, mock_stdout):
-        status = f'{self.green(Signs.OK)} '
-        msg = 'foo bar'
+        status = f"{self.green(Signs.OK)} "
+        msg = "foo bar"
 
-        expected_msg = self.reset(f'{status}{msg}').styled_string + '\n'
+        expected_msg = self.reset(f"{status}{msg}").styled_string + "\n"
         expected_len = len(expected_msg)
 
         self.term.ok(msg)
@@ -117,13 +133,13 @@ class TerminalTestCase(unittest.TestCase):
         self.assertEqual(ret, expected_msg)
         self.assertEqual(len(ret), expected_len)
 
-    @patch('sys.stdout', new_callable=StringIO)
+    @patch("sys.stdout", new_callable=StringIO)
     def test_warning(self, mock_stdout):
-        msg = 'foo bar'
+        msg = "foo bar"
 
-        status = f'{self.yellow(Signs.WARNING)} '
+        status = f"{self.yellow(Signs.WARNING)} "
 
-        expected_msg = self.reset(f'{status}{msg}').styled_string + '\n'
+        expected_msg = self.reset(f"{status}{msg}").styled_string + "\n"
         expected_len = len(expected_msg)
 
         self.term.warning(msg)
@@ -133,82 +149,27 @@ class TerminalTestCase(unittest.TestCase):
         self.assertEqual(ret, expected_msg)
         self.assertEqual(len(ret), expected_len)
 
-    @patch('sys.stdout', new_callable=StringIO)
+    @patch("sys.stdout", new_callable=StringIO)
     def test_print(self, mock_stdout):
-        expected_msg = self.reset('  foo bar').styled_string + '\n'
+        expected_msg = (
+            self.reset(f'{self.white(" ")} foo bar').styled_string + "\n"
+        )
 
-        self.term.print('foo bar')
+        self.term.print("foo bar")
 
         ret = mock_stdout.getvalue()
 
         self.assertEqual(len(ret), len(expected_msg))
         self.assertEqual(ret, expected_msg)
 
-    @patch('sys.stdout', new_callable=StringIO)
-    def test_add_indent(self, mock_stdout):
-        i = 6
-        expected_msg = self.reset(' ' * i + 'foo').styled_string + '\n'
-
-        self.term.add_indent(i - 2)
-        self.term.print('foo')
-
-        ret = mock_stdout.getvalue()
-
-        self.assertEqual(len(ret), len(expected_msg))
-        self.assertEqual(ret, expected_msg)
-
-        # clear the buffer
-        mock_stdout.truncate(0)
-        mock_stdout.seek(0)
-
-        j = 4
-        expected_msg = self.reset(' ' * (i + j) + 'bar').styled_string + '\n'
-
-        self.term.add_indent(j)
-        self.term.print('bar')
-
-        ret = mock_stdout.getvalue()
-
-        self.assertEqual(len(ret), len(expected_msg))
-        self.assertEqual(ret, expected_msg)
-
-        # clear the buffer
-        mock_stdout.truncate(0)
-        mock_stdout.seek(0)
-
-    @patch('sys.stdout', new_callable=StringIO)
-    def test_reset_indent(self, mock_stdout):
-        i = 6
-        expected_msg = self.reset(' ' * i + 'foo').styled_string + '\n'
-
-        self.term.add_indent(i - 2)
-        self.term.print('foo')
-
-        ret = mock_stdout.getvalue()
-
-        self.assertEqual(len(ret), len(expected_msg))
-        self.assertEqual(ret, expected_msg)
-
-        # clear the buffer
-        mock_stdout.truncate(0)
-        mock_stdout.seek(0)
-
-        expected_msg = self.reset('  bar').styled_string + '\n'
-
-        self.term.reset_indent()
-        self.term.print('bar')
-
-        ret = mock_stdout.getvalue()
-
-        self.assertEqual(len(ret), len(expected_msg))
-        self.assertEqual(ret, expected_msg)
-
-    @patch('sys.stdout', new_callable=StringIO)
+    @patch("sys.stdout", new_callable=StringIO)
     def test_with_indent(self, mock_stdout):
-        expected_msg = self.reset('    foo').styled_string + '\n'
+        expected_msg = (
+            self.reset(f'{self.white(" ")}   foo').styled_string + "\n"
+        )
 
         with self.term.indent(2):
-            self.term.print('foo')
+            self.term.print("foo")
 
             ret = mock_stdout.getvalue()
 
@@ -219,28 +180,28 @@ class TerminalTestCase(unittest.TestCase):
         mock_stdout.truncate(0)
         mock_stdout.seek(0)
 
-        expected_msg = self.reset('  bar').styled_string + '\n'
-        self.term.print('bar')
+        expected_msg = self.reset(f'{self.white(" ")} bar').styled_string + "\n"
+        self.term.print("bar")
 
         ret = mock_stdout.getvalue()
 
         self.assertEqual(len(ret), len(expected_msg))
         self.assertEqual(ret, expected_msg)
 
-    @patch('sys.stdout', new_callable=StringIO)
+    @patch("sys.stdout", new_callable=StringIO)
     def test_long_msg(self, mock_stdout):
         long_msg = (
-            'Lorem ipsum dolor sit amet, consetetur sadipscing elitr, '
-            'sed diam nonumy eirmod tempor invidunt ut labore et dolore magna'
-            ' aliquyam erat, sed diam voluptua.'
+            "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, "
+            "sed diam nonumy eirmod tempor invidunt ut labore et dolore magna"
+            " aliquyam erat, sed diam voluptua."
         )
         expected_msg = (
             self.reset(
-                '  Lorem ipsum dolor sit amet, consetetur sadipscing elitr, '
-                'sed diam nonumy eirmo\n  d tempor invidunt ut labore et'
-                ' dolore magna aliquyam erat, sed diam voluptua.'
+                f'{self.white(" ")} Lorem ipsum dolor sit amet, consetetur '
+                "sadipscing elitr, sed diam nonumy eirmo\n  d tempor invidunt "
+                "ut labore et dolore magna aliquyam erat, sed diam voluptua."
             ).styled_string
-            + '\n'
+            + "\n"
         )
         expected_len = len(expected_msg)
 
@@ -252,35 +213,5 @@ class TerminalTestCase(unittest.TestCase):
         self.assertEqual(len(ret), expected_len)
 
 
-class TerminalOutputApiTestCase(unittest.TestCase):
-    def setUp(self):
-        self.term = Mock(spec=Terminal)
-        _set_terminal(self.term)
-
-    def test_error(self):
-        error('foo bar')
-        self.term.error.assert_called_with('foo bar')
-
-    def test_fail(self):
-        fail('foo bar')
-        self.term.fail.assert_called_with('foo bar')
-
-    def test_info(self):
-        info('foo bar')
-        self.term.info.assert_called_with('foo bar')
-
-    def test_ok(self):
-        ok('foo bar')
-        self.term.ok.assert_called_with('foo bar')
-
-    def test_out(self):
-        out('foo bar')
-        self.term.print.assert_called_with('foo bar')
-
-    def test_warning(self):
-        warning('foo bar')
-        self.term.warning.assert_called_with('foo bar')
-
-
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
